@@ -1,5 +1,4 @@
 import argparse
-import glob
 import sys
 from gettext import gettext
 from typing import (
@@ -15,7 +14,7 @@ from .assertion import SnapshotAssertion
 from .constants import DISABLE_COLOR_ENV_VAR
 from .exceptions import FailedToLoadModuleMember
 from .extensions import DEFAULT_EXTENSION
-from .location import TestLocation
+from .location import PyTestLocation
 from .session import SnapshotSession
 from .terminal import (
     received_style,
@@ -27,6 +26,9 @@ from .utils import (
     import_module_member,
 )
 
+# Global to have access to the session in `pytest_runtest_logfinish` hook
+_syrupy: Optional["SnapshotSession"] = None
+
 
 def __default_extension_option(value: str) -> Any:
     try:
@@ -101,18 +103,6 @@ def pytest_assertrepr_compare(
     return None
 
 
-def __is_testpath(arg: str) -> bool:
-    return not arg.startswith("-") and bool(glob.glob(arg.split("::")[0]))
-
-
-def __is_testnode(arg: str) -> bool:
-    return __is_testpath(arg) and "::" in arg
-
-
-def __is_testmodule(arg: str) -> bool:
-    return arg == "--pyargs"
-
-
 def pytest_sessionstart(session: Any) -> None:
     """
     Initialize snapshot session before tests are collected and ran.
@@ -123,14 +113,10 @@ def pytest_sessionstart(session: Any) -> None:
         warn_unused_snapshots=config.option.warn_unused_snapshots,
         update_snapshots=config.option.update_snapshots,
         base_dir=config.rootdir,
-        is_providing_paths=any(
-            __is_testpath(arg) or __is_testmodule(arg)
-            for arg in config.invocation_params.args
-        ),
-        is_providing_nodes=any(
-            __is_testnode(arg) for arg in config.invocation_params.args
-        ),
+        invocation_args=config.invocation_params.args,
     )
+    global _syrupy
+    _syrupy = config._syrupy
     config._syrupy.start()
 
 
@@ -151,7 +137,21 @@ def pytest_collection_finish(session: Any) -> None:
     https://docs.pytest.org/en/latest/reference.html#_pytest.hookspec.pytest_collection_finish
     """
     for item in session.config._syrupy.filter_valid_items(session.items):
-        session.config._syrupy._ran_items[item] = True
+        session.config._syrupy._ran_items[item] = False
+
+
+def pytest_runtest_logfinish(nodeid: str) -> None:
+    """
+    At the end of running the runtest protocol for a single item.
+    https://docs.pytest.org/en/latest/reference.html#_pytest.hookspec.pytest_runtest_logfinish
+    """
+    global _syrupy
+    if not _syrupy:
+        return
+    for item in _syrupy._ran_items:
+        if getattr(item, "nodeid", None) == nodeid:
+            _syrupy._ran_items[item] = True
+            return
 
 
 def pytest_sessionfinish(session: Any, exitstatus: int) -> None:
@@ -180,6 +180,6 @@ def snapshot(request: Any) -> "SnapshotAssertion":
     return SnapshotAssertion(
         update_snapshots=request.config.option.update_snapshots,
         extension_class=request.config.option.default_extension,
-        test_location=TestLocation(request.node),
+        test_location=PyTestLocation(request.node),
         session=request.session.config._syrupy,
     )
