@@ -5,8 +5,10 @@ from typing import (
     Optional,
 )
 
+from syrupy.constants import PYTEST_NODE_SEP
 
-class TestLocation:
+
+class PyTestLocation:
     def __init__(self, node: Any):
         self._node = node
         self.filepath = self._node.fspath
@@ -17,8 +19,11 @@ class TestLocation:
 
     @property
     def classname(self) -> Optional[str]:
-        _, __, qualname = self._node.location
-        return ".".join(list(self.__valid_ids(qualname))[:-1]) or None
+        """
+        Pytest node names contain file path and module members delimited by `::`
+        Example tests/grouping/test_file.py::TestClass::TestSubClass::test_method
+        """
+        return ".".join(self._node.nodeid.split(PYTEST_NODE_SEP)[1:-1]) or None
 
     @property
     def filename(self) -> str:
@@ -31,6 +36,10 @@ class TestLocation:
         return str(self.testname)
 
     def __valid_id(self, name: str) -> str:
+        """
+        Take characters from the name while the result would be a valid python
+        identified. Example: "test_2[A]" returns "test_2" while "1_a" would return ""
+        """
         valid_id = ""
         for char in name:
             new_valid_id = f"{valid_id}{char}"
@@ -40,6 +49,10 @@ class TestLocation:
         return valid_id
 
     def __valid_ids(self, name: str) -> Iterator[str]:
+        """
+        Break a name path into valid name parts stopping at the first non valid name.
+        Example "TestClass.test_method_[1]" would yield ("TestClass", "test_method_")
+        """
         for n in name.split("."):
             valid_id = self.__valid_id(n)
             if valid_id:
