@@ -1,11 +1,12 @@
 import os
+import re
 
 from invoke import (
     exceptions,
     task,
 )
 
-import benchmarks
+from setup import install_requires
 
 
 def ctx_run(ctx, *args, **kwargs):
@@ -21,6 +22,18 @@ def clean(ctx):
     ctx_run(ctx, "rm -rf *.egg-info dist build __pycache__ .pytest_cache artifacts/*")
 
 
+def _parse_min_versions(requirements):
+    result = []
+    for req in sorted(requirements):
+        match = re.match(r"([\w_]+)>=([^,]+),.*", req)
+        if match is None:
+            continue
+        pkg_name = match.group(1)
+        min_version = match.group(2)
+        result.append(f"{pkg_name}=={min_version}")
+    return result
+
+
 @task
 def requirements(ctx, upgrade=False):
     """
@@ -40,6 +53,11 @@ def requirements(ctx, upgrade=False):
         f"{' '.join(args)} - -qo- | sed '/^-e / d' > dev_requirements.txt",
     )
 
+    with open("min_requirements.txt", "w", encoding="utf-8") as f:
+        min_requirements = _parse_min_versions(install_requires)
+        f.write("\n".join(min_requirements))
+        f.write("\n")
+
 
 @task
 def lint(ctx, fix=False):
@@ -110,6 +128,8 @@ def test(
 
 @task(help={"report": "Publish report as github status"})
 def benchmark(ctx, report=False):
+    import benchmarks
+
     benchmarks.main(report=report)
 
 
